@@ -154,21 +154,26 @@ open_file_ok_cb (GtkWidget *w,
 #endif
 
 		if (files != NULL) {
-			gchar *first = files->data;
-			if (path_is_dir (first))
+			char *first = files->data;
+			char *first_path;
+
+			first_path = g_build_path (G_DIR_SEPARATOR_S, base_dir, first, NULL);
+			if (path_is_dir (first_path)) {
 				fr_archive_add_directory (window->archive, 
 							  file_name_from_path (first), 
 							  base_dir, 
 							  FALSE,
 							  window->password,
 							  window->compression);
-			else 
+			} else 
 				fr_archive_add (window->archive,
 						files,
 						base_dir,
 						update,
 						window->password,
 						window->compression);
+
+			g_free (first_path);
 		}
 		
 		g_list_free (files);
@@ -335,7 +340,7 @@ add_cb (GtkWidget *widget,
  
 	data = g_new (DialogData, 1);
 	data->window = callback_data;
-	data->dialog = file_sel = gtk_file_selection_new (_("Add files"));
+	data->dialog = file_sel = gtk_file_selection_new (_("Add Files and Folders"));
 	gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (file_sel));
 
 	gtk_file_selection_set_select_multiple (GTK_FILE_SELECTION (file_sel), TRUE);
@@ -601,15 +606,16 @@ load_options_cb (GtkWidget  *w,
 	char       *options_dir;
 	char       *options_dir_slash;
 	
-	options_dir = g_strconcat (g_get_home_dir (), "/.file-roller/options", NULL);
+	options_dir = get_home_relative_dir (RC_OPTIONS_DIR);
+	options_dir_slash = g_strconcat (options_dir, "/", NULL);
+
 	ensure_dir_exists (options_dir, 0700);
-	g_free (options_dir);
 	
-	options_dir_slash = g_strconcat (g_get_home_dir (), "/.file-roller/options/", NULL);
-	
-	opt_sel = gtk_file_selection_new (_("Load options"));
+	opt_sel = gtk_file_selection_new (_("Load Options"));
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (opt_sel), 
 					 options_dir_slash);
+
+	g_free (options_dir);
 	g_free (options_dir_slash);
 	
 	g_object_set_data (G_OBJECT (opt_sel), "fr_file_sel", file_sel);
@@ -748,16 +754,17 @@ save_options_cb (GtkWidget  *w,
 	GtkWidget *opt_sel;
 	char      *options_dir;
 	char      *options_dir_slash;
-	
-	options_dir = g_strconcat (g_get_home_dir (), "/.file-roller/options", NULL);
+
+	options_dir = get_home_relative_dir (RC_OPTIONS_DIR);	
+	options_dir_slash = g_strconcat (options_dir, "/", NULL);
+
 	ensure_dir_exists (options_dir, 0700);
-	g_free (options_dir);
 	
-	options_dir_slash = g_strconcat (g_get_home_dir (), "/.file-roller/options/", NULL);
-	
-	opt_sel = gtk_file_selection_new (_("Save options"));
+	opt_sel = gtk_file_selection_new (_("Save Options"));
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION (opt_sel), 
 					 options_dir_slash);
+
+	g_free (options_dir);
 	g_free (options_dir_slash);
 	
 	g_object_set_data (G_OBJECT (opt_sel), "fr_file_sel", file_sel);
